"""Django app configuration for django-display-ids."""

from django.apps import AppConfig


class DjangoDisplayIdsConfig(AppConfig):
    """App configuration for django-display-ids."""

    name = "django_display_ids"
    verbose_name = "Django Display IDs"
    default_auto_field = "django.db.models.BigAutoField"
